# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# Copyright 2015 Modified by Mahmoud Mamdouh
# License: BSD (see file COPYING for details)

from __future__ import unicode_literals
from __future__ import print_function

from commondata.utils import Place, PlaceGenerator


class PlaceInEgypt(Place):

    def __unicode__(self):
        return self.name


class Country(PlaceInEgypt):
    value = 0

class Governorate(Country):
    value = 1

class City(Governorate):
    value = 2

class Region(City):
    value = 3

def root():

    p = PlaceGenerator()
    p.install(Country, Governorate, City, Region)
    p.set_args('name_en name_ar zip_code')

    egypt = p.country("Egypt","مصر")

    from .cairo import populate ; populate(p)
    from .giza import populate ; populate(p)
    from .alexandria import populate ; populate(p)
    from .damietta import populate ; populate(p)
    from .port_said import populate ; populate(p)
    
    return egypt



# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Giza", "الجيزة", "")
    p.city("Al Haram", "الهرم", "")
    p.city("King Faisel", "الملك فيصل", "")
    p.city("Memphis", "ممفيس", "")
    p.city("6th of October", "السادس من اكتوبر", "")
    p.city("Sheikh Zayed", "الشيخ زايد", "")
    p.city("Others", "اخرى", "")


# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Damietta", "دمياط", "")
    p.city("Ras El Bar", "رأس البر", "")
    p.city("New Damietta", "دمياط الجديدة", "")
    p.city("Faraskur", "فارسكور", "")
    p.city("Al Zarqa", "الزرقا", "")
    p.city("Kafr Saad", "كفر سعد", "")
    p.city("Others", "اخرى", "")


# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Alexandria","الإسكندري")
    p.city("Montazah","المنتزة")
    p.city("Alexandria Shark (East)","شرق الإسكندرية")
    p.city("Alexandria Wassat (Middle)","غرب الإسكندرية")
    p.city("Gomrok","الجمرك")
    p.city("Agami","العجمي")
    p.city("Amriya","الاميرية")
    p.city("Borg El Arab","برج العرب")
    p.city("Others","اخرى")


# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("El-Marg", "المرج", "")
    p.city("Al Salam", "السلام", "")
    p.city("Ain Shams", "عين شمس", "")
    p.city("Al-Matariyyah", "المطرية", "")
    p.city("Al Zeitoun", "الزيتون" , "")
    p.city("Haddaq Al Qubbah", "حدائق القبة", "")
    p.city("Al Nuzhah", "النزهة", "")
    p.city("Misr Al Jadidah", "مصر الجديدة", "")
    p.city("Al Waili", "الوايلي", "")
    p.city("Al Zawiyah Al Hamra", "الزاوية الحمراء", "")
    p.city("Al Sharabiyah", "الشرابية", "")
    p.city("Al Sajil", "السجل", "")
    p.city("Shobra", "شبرا", "")
    p.city("Rud Al Faraj", "روض الفرج", "")
    p.city("Bulaq", "بولاق", "")
    p.city("Al Azbakeya", "الأزبكية", "")
    p.city("Manshiyat Naser", "منشية نصر", "")
    p.city("Mokattam", "المقطم", "")
    p.city("Madinat Nasr", "مدينة نصر", "")
    p.city("Qasr al Nil", "قصر النيل", "")
    p.city("Al Zamalek", "الزمالك", "")
    p.city("Abdin", "عبدين", "")
    p.city("Al Muski", "الموسكي", "")
    p.city("Bab Al-Shaariyah", "باب الشعرية", "")
    p.city("Al Azhar", "الأزهر", "")
    p.city("Al Jamaliyah", "الجمالية", "")
    p.city("Al-Darb al Ahmar", "الدرب الأحمر", "")
    p.city("Al Sayidah Zaynab", "السيد زينب", "")
    p.city("Misr Al Qadimah", "مصر القديمة", "")
    p.city("Al Khalifa", "الخليفة", "")
    p.city("Al Basatin", "البساتين", "")
    p.city("Maadi", "المعادي", "")
    p.city("Turah", "طرة", "")
    p.city("15 May", "15 مايو", "")
    p.city("Helwan", "حلوان", "")
    p.city("Al-Tabin", "التبين", "")
    p.city("Qahirah al Jadidah", "القاهرة الجديدة", "")
    p.city("Al Shuruq", "الشروق", "")
    p.city("Badr", "بدر", "")
    p.city("Others", "اخرى", "")


from setuptools import setup

SETUP_INFO = dict(
    name='commondata.eg',
    version='0.0.3',
    install_requires=['commondata'],
    description="Common data about Egypt",
    license='BSD license',
    test_suite='tests',
    author='Mahmoud Mamdouh',
    author_email='sharedup@gmail.com',
    url="https://github.com/ExcellentServ/commondata-eg",
    classifiers="""\
Programming Language :: Python
Programming Language :: Python :: 2.6
Programming Language :: Python :: 2.7
Development Status :: 4 - Beta
Intended Audience :: Developers
License :: OSI Approved :: BSD License
Natural Language :: English
Natural Language :: Arabic
Operating System :: OS Independent""".splitlines())

SETUP_INFO.update(long_description=open('README.rst').read())

SETUP_INFO.update(packages=[str(n) for n in """
commondata.eg
""".splitlines() if n])

SETUP_INFO.update(namespace_packages=['commondata'])

if __name__ == '__main__':
    setup(**SETUP_INFO)



# -*- coding: UTF-8 -*-
# Copyright 2015 Mahmoud Mamdouh
# License: BSD (see file COPYING for details)


from __future__ import unicode_literals
__author__ = 'drx'

def populate(p):
    p.city("Port Said", "بورسعيد", "")
    p.city("Port Fouad", "بورفؤاد", "")
    p.city("Others", "اخرى", "")